pilas.actores.boton.Boton

Package pilas :: Package actores :: Module boton :: Class Boton |
[hide private]
[frames] | no frames]

# Class Boton

source code

                   object --+
                            |
    estudiante.Estudiante --+
                            |
                  actor.Actor --+
                                |
                               Boton

Known Subclasses:
  - sonido.Sonido

Representa un boton que reacciona al ser presionado.

.. image:: images/actores/boton_normal.png

Instance Methods | [hide private]
__init__(self, x=0, y=0, ruta_normal=`'``boton/boton_normal.png``'`, ruta_press=`'``boton/boton_press.png``'`, ruta_over=`'``boton/boton_over.png``'`) Constructor del Boton. | source code
_cargar_imagenes(self, ruta_normal, ruta_press, ruta_over) | source code
activar(self) | source code
conectar_normal(self, funcion, arg=`'``null``'`) Permite conectar un metodo para que sea ejecutado cuando el botón pase al estado normal. | source code
conectar_presionado(self, funcion, arg=`'``null``'`) Permite conectar un metodo para que sea ejecutado cuando el botón se presiona. | source code
conectar_sobre(self, funcion, arg=`'``null``'`) Permite conectar un metodo para que sea ejecutado cuando el ratón pasa por encima del botón. | source code
desactivar(self) | source code
desconectar_normal(self, funcion, arg=`'``null``'`) Elimina el método indicado asociado al estado normal del botón. | source code
desconectar_normal_todo(self) Elimina todas las funciones asociadas al estado normal del botón. | source code
desconectar_presionado(self, funcion, arg=`'``null``'`) Elimina el método indicado asociado al estado presinado del botón. | source code
desconectar_presionado_todo(self) Elimina todas las funciones asociadas al estado presionado del botón. | source code
desconectar_sobre(self, funcion, arg=`'``null``'`) Elimina el método indicado asociado al estado sobre del botón. | source code
desconectar_sobre_todo(self) Elimina todas las funciones asociadas al estado sobre del botón. | source code
detection_click_mouse(self, click) | source code
detection_end_click_mouse(self, end_click) | source code
detection_move_mouse(self, evento) | source code
ejecutar_funciones_normal(self) | source code
ejecutar_funciones_over(self) | source code
ejecutar_funciones_press(self) | source code
pintar_normal(self) Dibuja el botón en estado normal. | source code
pintar_presionado(self, ruta_press=`'``null``'`) Dibuja el botón en estado presinado. | source code
pintar_sobre(self) Dibuja el botón en estado sobre. | source code
Inherited from `actor.Actor`: `__cmp__`, `__mul__`, `__str__`, `actor_mas_cercano`, `actualizar`, `anexar`, `colisiona_con`, `colisiona_con_un_punto`, `decir`, `definir_centro`, `definir_color`, `definir_escala`, `definir_imagen`, `definir_posicion`, `definir_rotacion`, `definir_transparencia`, `destruir`, `dibujar`, `distancia_al_punto`, `distancia_con`, `duplicar`, `eliminar`, `es_fondo`, `esta_fuera_de_la_pantalla`, `get_abajo`, `get_arriba`, `get_derecha`, `get_espejado`, `get_fijo`, `get_imagen`, `get_izquierda`, `get_rotation`, `get_scale`, `get_scale_x`, `get_scale_y`, `get_transparencia`, `get_vx`, `get_vy`, `get_x`, `get_y`, `get_z`, `imitar`, `obtener_alto`, `obtener_ancho`, `obtener_centro`, `obtener_escala`, `obtener_imagen`, `obtener_posicion`, `obtener_rotacion`, `pre_actualizar`, `set_abajo`, `set_arriba`, `set_derecha`, `set_espejado`, `set_fijo`, `set_imagen`, `set_izquierda`, `set_rotation`, `set_scale`, `set_scale_x`, `set_scale_y`, `set_transparencia`, `set_x`, `set_y`, `set_z` Inherited from `actor.Actor` (private): `_eliminar_anexados`, `_interpretar_y_convertir_posicion` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__` Inherited from `estudiante.Estudiante`: `actualizar_comportamientos`, `actualizar_habilidades`, `agregar_habilidad`, `aprender`, `eliminar_comportamientos`, `eliminar_habilidad`, `eliminar_habilidades`, `hacer`, `hacer_luego`, `obtener_habilidad`, `tiene_comportamiento`, `tiene_habilidad` Inherited from `estudiante.Estudiante` (private): `_adoptar_el_siguiente_comportamiento`

Properties | [hide private]
Inherited from `actor.Actor`: `abajo`, `alto`, `ancho`, `arriba`, `centro`, `derecha`, `escala`, `escala_x`, `escala_y`, `espejado`, `fijo`, `imagen`, `izquierda`, `rotacion`, `transparencia`, `vx`, `vy`, `x`, `y`, `z` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, x=0, y=0, ruta_normal=`'``boton/boton_normal.png``'`, ruta_press=`'``boton/boton_press.png``'`, ruta_over=`'``boton/boton_over.png``'`) (Constructor) | source code
Constructor del Boton. :param x: Posición horizontal del Actor. :type x: int :param y: Posición vertical del Actor. :type y: int :param ruta_normal: Ruta de la imagen del boton en estado normal. :type ruta_normal: string :param ruta_press: Ruta de la imagen del boton cuando se presiona. :type ruta_press: string :param ruta_over: Ruta de la imagen del boton cuando el ratón pasa por encima. :type ruta_over: string Overrides: estudiante.Estudiante.__init__

### conectar_normal(self, funcion, arg=`'``null``'`) | source code
Permite conectar un metodo para que sea ejecutado cuando el botón pase al estado normal.
    >>> def cuando_deja_de_pulsar():
    >>>     b.pintar_normal()
    >>>
    >>> mi_boton.conectar_normal(cuando_deja_de_pulsar)
:param funcion: Método a llamar cuando el botón pase a estado Normal. :param arg: Argumentos a pasar a la funcion.

### conectar_presionado(self, funcion, arg=`'``null``'`) | source code
Permite conectar un metodo para que sea ejecutado cuando el botón se presiona.
    >>> def cuando_pulsan_el_boton():
    >>>     b.pintar_presionado()
    >>>
    >>> mi_boton.conectar_presionado(cuando_pulsan_el_boton)
:param funcion: Método a llamar cuando el botón pase a estado Normal. :param arg: Argumentos a pasar a la funcion.

### conectar_sobre(self, funcion, arg=`'``null``'`) | source code
Permite conectar un metodo para que sea ejecutado cuando el ratón pasa por encima del botón.
    >>> def cuando_pasa_sobre_el_boton():
    >>>     b.pintar_sobre()
    >>>
    >>> mi_boton.conectar_sobre(cuando_pasa_sobre_el_boton)
:param funcion: Método a llamar cuando el botón pase a estado Normal. :param arg: Argumentos a pasar a la funcion.

### desconectar_normal(self, funcion, arg=`'``null``'`) | source code
Elimina el método indicado asociado al estado normal del botón. :param funcion: Método al que se llama cuando el botón pasa estado Normal. :param arg: Argumentos que se pasaban a la funcion.

### desconectar_presionado(self, funcion, arg=`'``null``'`) | source code
Elimina el método indicado asociado al estado presinado del botón. :param funcion: Método al que se llama cuando el botón pasa estado Presionado. :param arg: Argumentos que se pasaban a la funcion.

### desconectar_sobre(self, funcion, arg=`'``null``'`) | source code
Elimina el método indicado asociado al estado sobre del botón. :param funcion: Método al que se llama cuando el botón pasa estado Sobre. :param arg: Argumentos que se pasaban a la funcion.

### pintar_presionado(self, ruta_press=`'``null``'`) | source code
Dibuja el botón en estado presinado. :param ruta_press: Opcional. Ruta de la imagen del boton presionado. :type ruta_press: string